==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>欢迎来到 %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>请注意，大小写锁定功能打开！</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>布局</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登陆</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>登陆失败</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>登陆成功</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>输入您的用户名和密码</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新启动</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>会话</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>选择您的用户，并输入密码</translation>
    </message>
</context>
</TS>

==> sddm_0.17.0.orig.tar.gz: sddm-0.17.0/data/translations/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>欢迎来到 %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>请注意，大小写锁定功能打开！</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>布局</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登陆</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>登陆失败</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>登陆成功</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>输入您的用户名和密码</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新启动</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>会话</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>选择您的用户，并输入密码</translation>
    </message>
</context>
</TS>
